@@ -2,19 +2,24 @@
 Implement the command-line tool interface.
 """
 import argparse
+import os
 import sys
 import diff_cover
 from diff_cover.diff_reporter import GitDiffReporter
-from git_diff import GitDiffTool
-from diff_cover.violations_reporter import XmlCoverageReporter, \
-    Pep8QualityReporter, PylintQualityReporter
-from diff_cover.report_generator import HtmlReportGenerator, \
-    StringReportGenerator, HtmlQualityReportGenerator, \
-    StringQualityReportGenerator
+from diff_cover.git_diff import GitDiffTool
+from diff_cover.git_path import GitPathTool
+from diff_cover.violations_reporter import (
+    XmlCoverageReporter, Pep8QualityReporter, PylintQualityReporter
+)
+from diff_cover.report_generator import (
+    HtmlReportGenerator, StringReportGenerator,
+    HtmlQualityReportGenerator, StringQualityReportGenerator
+)
 from lxml import etree
 
 COVERAGE_XML_HELP = "XML coverage report"
 HTML_REPORT_HELP = "Diff coverage HTML output"
+COMPARE_BRANCH_HELP = "Branch to compare"
 VIOLATION_CMD_HELP = "Which code quality tool to use"
 INPUT_REPORTS_HELP = "Pep8 or pylint reports to use"
 
@@ -58,6 +63,13 @@ def parse_coverage_args(argv):
         help=HTML_REPORT_HELP
     )
 
+    parser.add_argument(
+        '--compare-branch',
+        type=str,
+        default='origin/master',
+        help=COMPARE_BRANCH_HELP
+    )
+
     return vars(parser.parse_args(argv))
 
 
@@ -91,6 +103,13 @@ def parse_quality_args(argv):
         help=HTML_REPORT_HELP
     )
 
+    parser.add_argument(
+        '--compare-branch',
+        type=str,
+        default='origin/master',
+        help=COMPARE_BRANCH_HELP
+    )
+
     parser.add_argument(
         'input_reports',
         type=str,
@@ -102,14 +121,15 @@ def parse_quality_args(argv):
     return vars(parser.parse_args(argv))
 
 
-def generate_coverage_report(coverage_xml, html_report=None):
+def generate_coverage_report(coverage_xml, compare_branch, html_report=None):
     """
     Generate the diff coverage report, using kwargs from `parse_args()`.
     """
-    diff = GitDiffReporter(git_diff=GitDiffTool())
+    diff = GitDiffReporter(compare_branch, git_diff=GitDiffTool())
 
     xml_roots = [etree.parse(xml_root) for xml_root in coverage_xml]
-    coverage = XmlCoverageReporter(xml_roots)
+    git_path = GitPathTool(os.getcwd())
+    coverage = XmlCoverageReporter(xml_roots, git_path)
 
     # Build a report generator
     if html_report is not None:
@@ -123,11 +143,11 @@ def generate_coverage_report(coverage_xml, html_report=None):
     reporter.generate_report(output_file)
 
 
-def generate_quality_report(tool, html_report=None):
+def generate_quality_report(tool, compare_branch, html_report=None):
     """
     Generate the quality report, using kwargs from `parse_args()`.
     """
-    diff = GitDiffReporter(git_diff=GitDiffTool())
+    diff = GitDiffReporter(compare_branch, git_diff=GitDiffTool())
 
     if html_report is not None:
         reporter = HtmlQualityReportGenerator(tool, diff)
@@ -147,8 +167,11 @@ def main():
 
     if progname.endswith('diff-cover'):
         arg_dict = parse_coverage_args(sys.argv[1:])
-        generate_coverage_report(arg_dict['coverage_xml'],
-                                 html_report=arg_dict['html_report'])
+        generate_coverage_report(
+            arg_dict['coverage_xml'],
+            arg_dict['compare_branch'],
+            html_report=arg_dict['html_report'],
+        )
 
     elif progname.endswith('diff-quality'):
         arg_dict = parse_quality_args(sys.argv[1:])
@@ -168,7 +191,11 @@ def main():
 
             try:
                 reporter = reporter_class(tool, input_reports)
-                generate_quality_report(reporter, arg_dict['html_report'])
+                generate_quality_report(
+                    reporter,
+                    arg_dict['compare_branch'],
+                    arg_dict['html_report']
+                )
 
             # Close any reports we opened
             finally:
